@@ -49,6 +49,10 @@
 
 package com.openexchange.filestore.sproxyd;
 
+import static com.openexchange.java.Autoboxing.L;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.HashSet;
@@ -65,6 +69,7 @@ import com.openexchange.filestore.sproxyd.chunkstorage.Chunk;
 import com.openexchange.filestore.sproxyd.chunkstorage.ChunkStorage;
 import com.openexchange.filestore.sproxyd.impl.SproxydClient;
 import com.openexchange.filestore.utils.DefaultChunkedUpload;
+import com.openexchange.filestore.utils.TempFileHelper;
 import com.openexchange.filestore.utils.UploadChunk;
 import com.openexchange.java.Streams;
 import com.openexchange.java.util.UUIDs;
@@ -94,7 +99,20 @@ public class SproxydFileStorage implements FileStorage {
 
     @Override
     public String saveNewFile(InputStream file) throws OXException {
+        File tmpFile = null;
         try {
+            /*
+             * spool to file
+             */
+            if (!(file instanceof FileInputStream)) {
+                tmpFile = TempFileHelper.getInstance().newTempFile();
+                if (tmpFile != null) {
+                    file = Streams.transferToFileAndCreateStream(file, tmpFile);
+                }
+            }
+            /*
+             * proceed
+             */
             UUID documentId = UUID.randomUUID();
             long length = upload(documentId, file, 0);
             if (length <= 0) {
@@ -102,8 +120,11 @@ public class SproxydFileStorage implements FileStorage {
                 throw SproxydExceptionCode.UNEXPECTED_ERROR.create("Sproxyd storage cannot save an empty file");
             }
             return UUIDs.getUnformattedString(documentId);
+        } catch (IOException e) {
+            throw FileStorageCodes.IOERROR.create(e, e.getMessage());
         } finally {
             Streams.close(file);
+            TempFileHelper.deleteQuietly(tmpFile);
         }
     }
 
@@ -197,6 +218,7 @@ public class SproxydFileStorage implements FileStorage {
 
     @Override
     public long appendToFile(InputStream file, String name, long offset) throws OXException {
+        File tmpFile = null;
         try {
             UUID documentId = UUIDs.fromUnformattedString(name);
             Chunk lastChunk = chunkStorage.getLastChunk(documentId);
@@ -205,11 +227,23 @@ public class SproxydFileStorage implements FileStorage {
             }
             long currentSize = lastChunk.getOffset() + lastChunk.getLength();
             if (offset != currentSize) {
-                throw FileStorageCodes.INVALID_OFFSET.create(offset, name, currentSize);
+                throw FileStorageCodes.INVALID_OFFSET.create(L(offset), name, L(currentSize));
+            }
+            /*
+             * spool to file
+             */
+            if (!(file instanceof FileInputStream)) {
+                tmpFile = TempFileHelper.getInstance().newTempFile();
+                if (tmpFile != null) {
+                    file = Streams.transferToFileAndCreateStream(file, tmpFile);
+                }
             }
             return upload(documentId, file, offset);
+        } catch (IOException e) {
+            throw FileStorageCodes.IOERROR.create(e, e.getMessage());
         } finally {
             Streams.close(file);
+            TempFileHelper.deleteQuietly(tmpFile);
         }
     }
 
@@ -265,7 +299,7 @@ public class SproxydFileStorage implements FileStorage {
              */
             Chunk chunk = chunks.get(0);
             if (offset >= chunk.getLength() || length >= 0 && length > chunk.getLength() - offset) {
-                throw FileStorageCodes.INVALID_RANGE.create(offset, length, name, chunk.getLength());
+                throw FileStorageCodes.INVALID_RANGE.create(L(offset), L(length), name, L(chunk.getLength()));
             }
             long rangeStart = 0 < offset ? offset : 0;
             long rangeEnd = (0 < length ? rangeStart + length : chunk.getLength()) - 1;
@@ -278,7 +312,7 @@ public class SproxydFileStorage implements FileStorage {
         Chunk lastChunk = chunks.get(size - 1);
         long totalLength = lastChunk.getOffset() + lastChunk.getLength();
         if (offset >= totalLength || length >= 0 && length > totalLength - offset) {
-            throw FileStorageCodes.INVALID_RANGE.create(offset, length, name, totalLength);
+            throw FileStorageCodes.INVALID_RANGE.create(L(offset), L(length), name, L(totalLength));
         }
         long rangeStart = 0 < offset ? offset : 0;
         long rangeEnd = (0 < length ? rangeStart + length : totalLength) - 1;
