@@ -234,7 +234,7 @@ public class SproxydClient {
         }
 
         if (Utils.endpointUnavailable(endpoint.getBaseUrl(), httpClient)) {
-            LOG.warn("Sproxyd endpoint is unavailable: " + endpoint);
+            LOG.warn("Sproxyd endpoint is unavailable: {}", endpoint);
             endpoints.blacklist(endpoint.getBaseUrl());
         }
 
